#include "mex.h"
#include "math.h"

#if NAN_EQUALS_ZERO
#define IsNonZero(d) ((d)!=0.0 || mxIsNaN(d))
#else
#define IsNonZero(d) ((d)!=0.0)
#endif

#define de(a,b) detectedEdges[(a-1) + (b-1)*lx]
#define gt(a,b) groundTruth[(a-1) + (b-1)*lx]


struct edgePxl{
    int x;
    int y;
};
                 
                    
//computePFOM(lx,ly,detectedEdges,groundTruth)
void mexFunction(int nlhs,       mxArray *plhs[],
		 int nrhs, const mxArray *prhs[])
{
    int x,y,i,lx,ly;
    int nGtPxls,nDePxls;
    double pfom,d,alpha,newd;
    bool * detectedEdges;
    bool * groundTruth;
    edgePxl * gtPxls;
    
     
    if (nrhs != 4) {
        mexErrMsgTxt("Four input arguments required.");
    } 
        
    lx = mxGetPr(prhs[0])[0];
    ly = mxGetPr(prhs[1])[0];
    detectedEdges = mxGetLogicals(prhs[2]);
    groundTruth = mxGetLogicals(prhs[3]);
    
    nGtPxls = 0;
    for(x = 1; x<=lx;x++){
        for(y = 1;y<=ly;y++){
            nGtPxls += gt(x,y);
            
        }
    }
    
    gtPxls = new edgePxl[nGtPxls];
    
    nGtPxls = 0;
    for(x = 1; x<=lx;x++){
        for(y = 1;y<=ly;y++){
            if(gt(x,y)){
                gtPxls[nGtPxls].x = x;
                gtPxls[nGtPxls].y = y;

                nGtPxls++;
            }
        }
    }
    pfom = 0;
    nDePxls = 0;
    alpha = 1.0/9.0;
    for(x = 1; x<=lx;x++){
        for(y = 1;y<=ly;y++){
            if(de(x,y)){
                d = (double)(lx*lx + ly*ly);
                for(i = 0;i<nGtPxls;i++){
                    newd = (x - gtPxls[i].x)*(x - gtPxls[i].x) + (y - gtPxls[i].y)*(y - gtPxls[i].y);
                    if(newd < d) {
                        d = newd;
                    }
                }
                nDePxls++;
                pfom += 1.0/(1.0 + alpha*d);
           }
        }
    }
    delete[] gtPxls;
    pfom = pfom/(nDePxls > nGtPxls ? nDePxls : nGtPxls);
    plhs[0] = mxCreateDoubleMatrix(1,1, mxREAL);
    
    mxGetPr(plhs[0])[0] = pfom;
      
}
