% This script reproduces figure 10 and the results of table 3 from                                       % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filenameTestImg = 'B0.png';
filenameGroundTruth = ['Mock Ridge Images',filesep,'B_groundtruth.png'];

groundtruth = imread(filenameGroundTruth)<255;
boundaryMask = ones(size(groundtruth));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;
groundtruth = groundtruth.*boundaryMask;
groundtruth = logical(groundtruth);


imgs = readTestData(filenameTestImg,['.',filesep,'Mock Ridge Images'],'noise','blur');


pfomResults = zeros(1,length(imgs));


waveletEffSupp = 100;
gaussianEffSupp = 40;
scalesPerOctave = 4;
shearLevel = 3; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.3;
octaves = 3.5;
onlyPositiveOrNegativeLines = 1;
minimalContrast = 13; 
offset = 1; %in octaves
thinningThreshold = 0.1;

complexShearletSystem = CSHRMgetContRidgeSystem(size(groundtruth,1),size(groundtruth,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));

for k = 1:length(imgs);
    img = imgs{k};
    [ridges,~] = CSHRMgetRidges(img,complexShearletSystem,minimalContrast,offset,onlyPositiveOrNegativeLines);
    ridges = CSHRMthinToLines(ridges,thinningThreshold);
    ridges = ridges.*boundaryMask;
    pfomResults(k) = computePFOM(size(img,1),size(img,2),logical(ridges),logical(groundtruth));   
    if ismember(k,[1,13,20])
        imgOverlay = CSHRMgetOverlay(img,ridges);

        figure; image(imgOverlay);axis off; axis equal;
        labels(1) = 'a';
        labels(13) = 'b';
        labels(20) = 'c';
        title(['Figure 10 ',labels(k)]);
    end
end

disp(round(100*pfomResults)/100);

%% Phase Congruency
%     For the phase congruency method, phasecong3 (see www.peterkovesi.com) was applied with the following parameters
%
%     nScale = 8;
%     nOrient = 8;
%     minWaveLength = 3;
%     scalingFactor = 1.6;
%     sigmaOnf = 0.6;
%     k = 3.0;
%     cutOff = 0.5;
%     g = 10;
%     noiseMethod = 35;
%     featureThresh = pi/6;
%
%     Postprocessing included the application of nonmaxsup (radius = 1.5), hysthresh and
%     Inf thinning with bwmorph. Furthermore, only phase angles with
%     abs(phaseAngle) < pi/6 were considered.