% This script reproduces figure 11 from                                                                 % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = ['Mock Ridge Images',filesep,'B0_blur_10_noise_050.png'];

img = double(imread(filename));


boundaryMask = ones(size(img));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;

waveletEffSupp = 70;
gaussianEffSupp = 40;
scalesPerOctave = 4;
shearLevel = 4; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.3;
octaves = 3;
onlyPositiveOrNegativeLines = 1;
minimalContrast = 20; 
offset = 1; %in octaves
thinningThreshold = 0.1;

complexShearletSystem = CSHRMgetContRidgeSystem(size(img,1),size(img,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));

[ridges,orientations] = CSHRMgetRidges(img,complexShearletSystem,minimalContrast,offset,onlyPositiveOrNegativeLines);
ridges = CSHRMthinToLines(ridges,thinningThreshold);
ridges = (ridges.*boundaryMask);
orientations(~ridges) = -1;
curvature = CSHRMgetCurvatureMex(orientations);    

imgOris = CSHRMrgbFromOrientations(orientations);
imgCurv = CSHRMrgbFromCurvature(curvature,5);

figure; image(imgCurv);axis off; axis equal;title('Figure 10 b');
figure; image(imgOris);axis off; axis equal;title('Figure 10 a');


%% Phase Congruency
%
%     phasecong3 (see www.peterkovesi.com) was applied with the following parameters
%
%     nScale = 8;
%     nOrient = 8;
%     minWaveLength = 3;
%     scalingFactor = 1.6;
%     sigmaOnf = 0.6;
%     k = 3.0;
%     cutOff = 0.5;
%     g = 10;
%     noiseMethod = 35;
%
%     Postprocessing included the application of nonmaxsup (radius = 1.5), hysthresh and
%     Inf thinning with bwmorph. Furthermore, only phase angles with
%     abs(phaseAngle) < pi/6 were considered. The curvature was computed
%     with CSHRMgetCurvatureMex from the orientations returned by
%     phasecong3.
    
