% This script reproduces figure 12 from                                                                 % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

img = dlmread(['Flame Images',filesep,'K05_OH_full.txt']);

%% system parameters
rows = size(img,1);
cols = size(img,2);
waveletEffSupp = 100;
gaussianEffSupp = 25;
scalesPerOctave = 2;
shearLevel = 4; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.8;
octaves = 4;
pivotScales = 'lowest';

%% edge detection parameters
minimalContrast = 70; 
offset = 1; %in octaves

%% thinning parameters
thinningThreshold = 0.1;

%% edge detection
complexShearletSystem = CSHRMgetContEdgeSystem(rows,cols,waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));
[edges,orientations] = CSHRMgetEdges(img,complexShearletSystem,minimalContrast,offset,pivotScales);

edgesThinned = CSHRMthinToLines(edges,thinningThreshold);
orientationsThinned = orientations;
orientationsThinned(~edgesThinned) = -1;
curvature = CSHRMgetCurvatureMex(orientationsThinned);

imgRgb = CSHRMgetOverlay(img,zeros(size(img)));
imgOverlayRgb = CSHRMgetOverlay(img,edges);
imgOverlayThinnedRgb = CSHRMgetOverlay(img,edgesThinned);
imgOris = CSHRMrgbFromOrientations(orientationsThinned);
imgCurv = CSHRMrgbFromCurvature(curvature,15);

figure; image(imgCurv);axis off; axis equal;title('Figure 11 e');
figure; image(imgOris);axis off; axis equal;title('Figure 11 d');
figure; image(imgOverlayThinnedRgb);axis off; axis equal;title('Figure 11 c');
figure; image(imgOverlayRgb);axis off; axis equal;title('Figure 11 b');
figure; image(imgRgb);axis off; axis equal;title('Figure 11 a');