% This script reproduces figure 13 from                                                                 % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

img = fliplr(dlmread(['Flame Images',filesep,'K05_CH_full.txt']));

%% system parameters
rows = size(img,1);
cols = size(img,2);
waveletEffSupp = 60;
gaussianEffSupp = 20;
scalesPerOctave = 4;
shearLevel = 3; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.2;
octaves = 4;
onlyPositive = 1;

saveResults = 1;

%% edge detection parameters
minimalContrast = 150; 
offset = 1; %in octaves

%% thinning parameters
thinningThreshold = 0.1;


%% ridge detection

complexShearletSystem = CSHRMgetContRidgeSystem(rows,cols,waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));

[ridges,orientations] = CSHRMgetRidges(img,complexShearletSystem,minimalContrast,offset,onlyPositive);

linesThinned = CSHRMthinToLines(ridges,thinningThreshold);
orientationsThinned = orientations;
orientationsThinned(~linesThinned) = -1;
curvature = CSHRMgetCurvatureMex(orientationsThinned);

imgRgb = CSHRMgetOverlay(img,zeros(size(img)));
imgOverlayRgb = CSHRMgetOverlay(img,ridges);
imgOverlayThinnedRgb = CSHRMgetOverlay(img,linesThinned);
imgOris = CSHRMrgbFromOrientations(orientationsThinned);
imgCurv = CSHRMrgbFromCurvature(curvature,15);

figure; image(imgCurv);axis off; axis equal;title('Figure 12 e');
figure; image(imgOris);axis off; axis equal;title('Figure 12 d');
figure; image(imgOverlayThinnedRgb);axis off; axis equal;title('Figure 12 c');
figure; image(imgOverlayRgb);axis off; axis equal;title('Figure 12 b');
figure; image(imgRgb);axis off; axis equal;title('Figure 12 a');



