% This script reproduces figure 6 from                                                                  % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = ['Mock Edge Images',filesep,'A0_blur_10_noise_050.png'];

img = double(imread(filename));

boundaryMask = ones(size(img));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;


waveletEffSupp = 100;
gaussianEffSupp = 50;
scalesPerOctave = 2;
shearLevel = 4; %i.e. 2^shearLevel different orientations on each scale
alpha = 1;
octaves = 4;
minimalContrast = 20; 
offset = 1; %in octaves
thinningThreshold = 0.1;
pivotScales = 'lowest';

complexShearletSystem = CSHRMgetContEdgeSystem(size(img,1),size(img,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));
[edges,orientations] = CSHRMgetEdges(img,complexShearletSystem,minimalContrast,offset,pivotScales);
edges = (edges.*boundaryMask);
edgesResultsThinned = CSHRMthinToLines(edges,thinningThreshold);
orientations(~edgesResultsThinned) = -1;
curvature = CSHRMgetCurvatureMex(orientations);
img = img.*boundaryMask;

imgRgb = CSHRMgetOverlay(img,zeros(size(img)));
imgOverlayRgb = CSHRMgetOverlay(img,edges);
imgOverlayThinnedRgb = CSHRMgetOverlay(img,edgesResultsThinned);
imgOris = CSHRMrgbFromOrientations(orientations);
imgCurv = CSHRMrgbFromCurvature(curvature,5);


figure; image(imgCurv);axis off; axis equal;title('Figure 5 e');
figure; image(imgOris);axis off; axis equal;title('Figure 5 d');
figure; image(imgOverlayThinnedRgb);axis off; axis equal;title('Figure 5 c');
figure; image(imgOverlayRgb);axis off; axis equal;title('Figure 5 b');
figure; image(imgRgb);axis off; axis equal;title('Figure 5 a');
