% This script reproduces figure 7 and the results of table 1 from                                       % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = 'A0.png';
filenameGroundTruth = ['Mock Edge Images',filesep,'A_groundtruth.png'];

imgs = readTestData(filename, ['.',filesep,'Mock Edge Images'],'noise','blur');


groundtruth = imread(filenameGroundTruth)<255;
boundaryMask = ones(size(groundtruth));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;
groundtruth = groundtruth.*boundaryMask;
groundtruth = logical(groundtruth);



pfomResults = zeros(1,length(imgs));

waveletEffSupp = 120;
gaussianEffSupp = 50;
scalesPerOctave = 2;
shearLevel = 3; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.8;
octaves = 4;
minimalContrast = 10; 
offset = 1; %in octaves
thinningThreshold = 0.2;
pivotScales = 'lowest';
    
complexShearletSystem = CSHRMgetContEdgeSystem(size(groundtruth,1),size(groundtruth,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));

for k = 1:20
    img = imgs{k};
    [edges,~] = CSHRMgetEdges(img,complexShearletSystem,minimalContrast,offset,pivotScales);
    edges = CSHRMthinToLines(edges,thinningThreshold);
    edges = edges.*boundaryMask;
    pfomResults(k) = computePFOM(size(img,1),size(img,2),logical(edges),logical(groundtruth));    
    
    if k == 20
        imgOverlay = CSHRMgetOverlay(img,edges);

        figure; image(imgOverlay);axis off; axis equal;
        title('Figure 6 a');
    end
end

disp(round(100*pfomResults)/100);

%% Canny 
%    For the Canny edge detector, we applied to MATLAB implementation, that
%    is
%
%    edges = edge(img,'canny',thresh,sigma);
%    edges = bwmorph(logical(edges),'thin',Inf);    
%
%    with tresh = [0.1,0.28] and sigma = 2.7. 


%% Sobel 
%    For the Sobel edge detector, we applied to MATLAB implementation, that
%    is
%
%    edges = edge(img,'sobel',thresh);
%    edges = bwmorph(logical(edges),'thin',Inf);    
%
%    with thresh = 29.

%% Phase Congruency    
%
%     phasecong3 (see www.peterkovesi.com) was applied with the following parameters
%
%     nScale = 4;
%     nOrient = 8;
%     minWaveLength = 3;
%     scalingFactor = 3;
%     sigmaOnf = 0.55;
%     k = 2.0;
%     cutOff = 0.5;
%     g = 10;
%     noiseMethod = 20;
%
%     Postprocessing included the application of nonmaxsup (radius = 1.5), hysthresh and
%     Inf thinning with bwmorph.


%% Shearlet Edge Detector
%     The code for the shearlet edge detector was kindly provided by Demetrio Labate. To improve the performance
%     on noisy data, we added preprocessing with a Gaussian kerne, i.e.
%
%     gaussKernel = fspecial('gaussian',ceil(sigma)*8,sigma);
%     x = imfilter(x, gaussKernel, 'conv', 'replicate');
%
%     with sigma = 2.5.