% This script reproduces figure 8 from                                                                 % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = ['Mock Edge Images',filesep,'A0_blur_10_noise_050.png'];

img = double(imread(filename));


boundaryMask = ones(size(img));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;

   
waveletEffSupp = 100;
gaussianEffSupp = 50;
scalesPerOctave = 2;
shearLevel = 4; %i.e. 2^shearLevel different orientations on each scale
alpha = 1;
octaves = 4;
minimalContrast = 20; 
offset = 1; %in octaves
thinningThreshold = 0.1;
pivotScales = 'lowest';


complexShearletSystem = CSHRMgetContEdgeSystem(size(img,1),size(img,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));
[edges,orientations] = CSHRMgetEdges(img,complexShearletSystem,minimalContrast,offset,pivotScales);
edges = CSHRMthinToLines(edges,thinningThreshold);
edges = (edges.*boundaryMask);
orientations(~edges) = -1;
curvature = CSHRMgetCurvatureMex(orientations);   

imgOris = CSHRMrgbFromOrientations(orientations);
imgCurv = CSHRMrgbFromCurvature(curvature,5);

figure; image(imgCurv);axis off; axis equal;title('Figure 10 d');
figure; image(imgOris);axis off; axis equal;title('Figure 10 a');


  
%% Phase Congruency    
%
%     phasecong3 (see www.peterkovesi.com) was applied with the following parameters
%
%     nScale = 4;
%     nOrient = 8;
%     minWaveLength = 3;
%     scalingFactor = 3;
%     sigmaOnf = 0.55;
%     k = 2.0;
%     cutOff = 0.5;
%     g = 10;
%     noiseMethod = 20;
%
%     Postprocessing included the application of nonmaxsup (radius = 1.5), hysthresh and
%     Inf thinning with bwmorph. The curvature was computed with CSHRMgetCurvatureMex from the orientations returned by
%     phasecong3.     

%% Shearlet Edge Detector
%     The code for computing the results depicted in figures 8c and 8f was kindly provided by Demetrio Labate. To improve the performance
%     on noisy data, we added preprocessing with a Gaussian kerne, i.e.
%
%
%     gaussKernel = fspecial('gaussian',ceil(sigma)*8,sigma);
%     x = imfilter(x, gaussKernel, 'conv', 'replicate');
%
%     with sigma = 2.5.
%
%     The curvature was again computed with CSHRMgetCurvatureMex.
