% This script reproduces figure 9 from                                                                 % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

filename = ['Mock Ridge Images',filesep,'B0_blur_10_noise_050.png'];

img = double(imread(filename));

boundaryMask = ones(size(img));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;


waveletEffSupp = 70;
gaussianEffSupp = 40;
scalesPerOctave = 4;
shearLevel = 4; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.3;
octaves = 3;
minimalContrast = 20; 
offset = 1; %in octaves
thinningThreshold = 0.1;
onlyPositiveOrNegativeLines = 1;

complexShearletSystem = CSHRMgetContRidgeSystem(size(img,1),size(img,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));
[ridges,orientations] = CSHRMgetRidges(img,complexShearletSystem,minimalContrast,offset,onlyPositiveOrNegativeLines);
ridges = (ridges.*boundaryMask);
edgesResultsThinned = CSHRMthinToLines(ridges,thinningThreshold);
orientations(~edgesResultsThinned) = -1;
curvature = CSHRMgetCurvatureMex(orientations);

img = img.*boundaryMask;

imgRgb = CSHRMgetOverlay(img,zeros(size(img)));
imgOverlayRgb = CSHRMgetOverlay(img,ridges);
imgOverlayThinnedRgb = CSHRMgetOverlay(img,edgesResultsThinned);
imgOris = CSHRMrgbFromOrientations(orientations);
imgCurv = CSHRMrgbFromCurvature(curvature,5);

figure; image(imgCurv);axis off; axis equal;title('Figure 8 e');
figure; image(imgOris);axis off; axis equal;title('Figure 8 d');
figure; image(imgOverlayThinnedRgb);axis off; axis equal;title('Figure 8 c');
figure; image(imgOverlayRgb);axis off; axis equal;title('Figure 8 b');
figure; image(imgRgb);axis off; axis equal;title('Figure 8 a');
