% This script the results of table 2 from                                       % 
% Rafael Reisenhofer, Johannes Kiefer and Emily J. King: Shearlet-Based Detection of Flame Fronts, 2015.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


imgs{1} = double(imread(['.',filesep,'Mock Edge Images',filesep,'A0_blur_00_noise_000_poisson.png']));
imgs{2} = double(imread(['.',filesep,'Mock Edge Images',filesep,'A0_blur_00_noise_020_poisson.png']));
imgs{3} = double(imread(['.',filesep,'Mock Edge Images',filesep,'A0_blur_00_noise_050_poisson.png']));
imgs{4} = double(imread(['.',filesep,'Mock Edge Images',filesep,'A0_blur_00_noise_080_poisson.png']));
imgs{5} = double(imread(['.',filesep,'Mock Edge Images',filesep,'A0_blur_00_noise_100_poisson.png']));


filenameGroundTruth = 'A_groundtruth.png';


groundtruth = imread(filenameGroundTruth)<255;
boundaryMask = ones(size(groundtruth));
boundaryMask([1:5,(end-4):end],:) = 0;
boundaryMask(:,[1:5,(end-4):end]) = 0;
groundtruth = groundtruth.*boundaryMask;
groundtruth = logical(groundtruth);

pfomResults = zeros(1,length(imgs));




waveletEffSupp = 120;
gaussianEffSupp = 50;
scalesPerOctave = 2;
shearLevel = 3; %i.e. 2^shearLevel different orientations on each scale
alpha = 0.8;
octaves = 4;
minimalContrast = 10; 
offset = 1; %in octaves
thinningThreshold = 0.2;
pivotScales = 'lowest';
    
complexShearletSystem = CSHRMgetContEdgeSystem(size(groundtruth,1),size(groundtruth,2),waveletEffSupp,gaussianEffSupp,scalesPerOctave,shearLevel,alpha,1:floor(octaves*scalesPerOctave));

for k = 1:5
    img = imgs{k};
    [edges,~] = CSHRMgetEdges(img,complexShearletSystem,minimalContrast,offset,pivotScales);
    edges = CSHRMthinToLines(edges,thinningThreshold);
    edges = (edges.*boundaryMask);
    pfomResults(k) = computePFOM(size(img,1),size(img,2),logical(edges),logical(groundtruth));    
end

disp(round(100*pfomResults)/100);


%% Canny 
%    For the Canny edge detector, we applied to MATLAB implementation, that
%    is
%
%    edges = edge(img,'canny',thresh,sigma);
%    edges = bwmorph(logical(edges),'thin',Inf);    
%
%    with tresh = [0.1,0.28] and sigma = 2.7. 


%% Sobel 
%    For the Sobel edge detector, we applied to MATLAB implementation, that
%    is
%
%    edges = edge(img,'sobel',thresh);
%    edges = bwmorph(logical(edges),'thin',Inf);    
%
%    with thresh = 29.

%% Phase Congruency    
%
%     phasecong3 (see www.peterkovesi.com) was applied with the following parameters
%
%     nScale = 4;
%     nOrient = 8;
%     minWaveLength = 3;
%     scalingFactor = 3;
%     sigmaOnf = 0.55;
%     k = 2.0;
%     cutOff = 0.5;
%     g = 10;
%     noiseMethod = 20;
%
%     Postprocessing included the application of nonmaxsup (radius = 1.5), hysthresh and
%     Inf thinning with bwmorph.


%% Shearlet Edge Detector
%     The code for the shearlet edge detector was kindly provided by Demetrio Labate. To improve the performance
%     on noisy data, we added preprocessing with a Gaussian kerne, i.e.
%
%     gaussKernel = fspecial('gaussian',ceil(sigma)*8,sigma);
%     x = imfilter(x, gaussKernel, 'conv', 'replicate');
%
%     with sigma = 2.5.